==> iaxmodem_1.1.0~dfsg.orig.tar.gz: iaxmodem-1.1.0/lib/spandsp/src/v27ter_rx_2400_fixed_rrc.h <==
#define PULSESHAPER_2400_GAIN        32767.000000f
#define PULSESHAPER_2400_COEFF_SETS  12
static const complexi16_t pulseshaper_2400[PULSESHAPER_2400_COEFF_SETS][27] =
{
    {
        {       0,        0},     /* Filter 0 */
        {     -58,      179},
        {     -42,       -6},
        {       0,      217},
        {    -518,       82},
        {    -233,     -719},
        {     686,     -349},
        {     261,      359},
        {     195,     -195},
        {    1096,      796},
        {   -1202,     2359},
        {   -3745,    -1216},
        {     778,    -4918},
        {    5561,        0},
        {     869,     5492},
        {   -4735,     1538},
        {   -1787,    -3508},
        {    2142,    -1556},
        {     958,      958},
        {    -162,      223},
        {     396,      201},
        {    -238,      732},
        {    -747,     -118},
        {       0,     -524},
        {     215,      -34},
        {     -13,      -41},
        {     167,      -85}
    },
    {
        {       0,        0},     /* Filter 1 */
        {     -56,      172},
        {     -25,       -4},
        {       0,      242},
        {    -542,       85},
        {    -237,     -730},
        {     675,     -344},
        {     235,      323},
        {     250,     -250},
        {    1178,      856},
        {   -1252,     2458},
        {   -3839,    -1247},
        {     789,    -4985},
        {    5584,        0},
        {     865,     5466},
        {   -4667,     1516},
        {   -1741,    -3418},
        {    2052,    -1491},
        {     886,      886},
        {    -118,      163},
        {     433,      221},
        {    -241,      742},
        {    -734,     -116},
        {       0,     -500},
        {     190,      -30},
        {     -18,      -57},
        {     173,      -88}
    },
    {
        {       0,        0},     /* Filter 2 */
        {     -53,      165},
        {      -6,       -1},
        {       0,      268},
        {    -565,       89},
        {    -240,     -739},
        {     661,     -337},
        {     207,      285},
        {     307,     -307},
        {    1262,      917},
        {   -1302,     2556},
        {   -3932,    -1277},
        {     799,    -5050},
        {    5603,        0},
        {     860,     5435},
        {   -4596,     1493},
        {   -1695,    -3326},
        {    1962,    -1426},
        {     816,      816},
        {     -76,      104},
        {     468,      238},
        {    -243,      750},
        {    -720,     -114},
        {       0,     -475},
        {     166,      -26},
        {     -23,      -72},
        {     177,      -90}
    },
    {
        {       0,        0},     /* Filter 3 */
        {     -50,      156},
        {      12,        1},
        {       0,      294},
        {    -587,       93},
        {    -242,     -747},
        {     645,     -328},
        {     177,      244},
        {     365,     -365},
        {    1347,      978},
        {   -1353,     2655},
        {   -4023,    -1307},
        {     809,    -5111},
        {    5618,        0},
        {     855,     5400},
        {   -4522,     1469},
        {   -1647,    -3233},
        {    1873,    -1361},
        {     748,      748},
        {     -35,       48},
        {     501,      255},
        {    -245,      756},
        {    -704,     -111},
        {       0,     -449},
        {     142,      -22},
        {     -28,      -87},
        {     181,      -92}
    },
    {
        {       0,        0},     /* Filter 4 */
        {     -47,      147},
        {      32,        5},
        {       0,      320},
        {    -609,       96},
        {    -244,     -753},
        {     627,     -319},
        {     146,      201},
        {     425,     -425},
        {    1433,     1041},
        {   -1403,     2753},
        {   -4112,    -1336},
        {     818,    -5168},
        {    5628,        0},
        {     849,     5361},
        {   -4445,     1444},
        {   -1599,    -3139},
        {    1784,    -1296},
        {     680,      680},
        {       4,       -6},
        {     531,      270},
        {    -246,      759},
        {    -687,     -108},
        {       0,     -423},
        {     119,      -18},
        {     -32,     -101},
        {     184,      -94}
    },
    {
        {       0,        0},     /* Filter 5 */
        {     -44,      137},
        {      53,        8},
        {       0,      346},
        {    -630,       99},
        {    -246,     -757},
        {     607,     -309},
        {     113,      155},
        {     486,     -486},
        {    1519,     1104},
        {   -1452,     2851},
        {   -4199,    -1364},
        {     827,    -5222},
        {    5634,        0},
        {     842,     5318},
        {   -4366,     1418},
        {   -1551,    -3044},
        {    1695,    -1231},
        {     614,      614},
        {      42,      -58},
        {     559,      284},
        {    -247,      760},
        {    -669,     -106},
        {       0,     -398},
        {      96,      -15},
        {     -37,     -114},
        {     187,      -95}
    },
    {
        {       0,        0},     /* Filter 6 */
        {     -40,      126},
        {      74,       11},
        {       0,      372},
        {    -650,      103},
        {    -247,     -760},
        {     584,     -297},
        {      78,      108},
        {     550,     -550},
        {    1607,     1167},
        {   -1502,     2948},
        {   -4284,    -1391},
        {     835,    -5272},
        {    5637,        0},
        {     835,     5272},
        {   -4284,     1391},
        {   -1502,    -2948},
        {    1607,    -1167},
        {     550,      550},
        {      78,     -108},
        {     584,      297},
        {    -247,      760},
        {    -650,     -103},
        {       0,     -372},
        {      74,      -11},
        {     -40,     -126},
        {     188,      -96}
    },
    {
        {       0,        0},     /* Filter 7 */
        {     -37,      114},
        {      96,       15},
        {       0,      398},
        {    -669,      106},
        {    -247,     -760},
        {     559,     -284},
        {      42,       58},
        {     614,     -614},
        {    1695,     1231},
        {   -1551,     3044},
        {   -4366,    -1418},
        {     842,    -5318},
        {    5634,        0},
        {     827,     5222},
        {   -4199,     1364},
        {   -1452,    -2851},
        {    1519,    -1104},
        {     486,      486},
        {     113,     -155},
        {     607,      309},
        {    -246,      757},
        {    -630,      -99},
        {       0,     -346},
        {      53,       -8},
        {     -44,     -137},
        {     189,      -96}
    },
    {
        {       0,        0},     /* Filter 8 */
        {     -32,      101},
        {     119,       18},
        {       0,      423},
        {    -687,      108},
        {    -246,     -759},
        {     531,     -270},
        {       4,        6},
        {     680,     -680},
        {    1784,     1296},
        {   -1599,     3139},
        {   -4445,    -1444},
        {     849,    -5361},
        {    5628,        0},
        {     818,     5168},
        {   -4112,     1336},
        {   -1403,    -2753},
        {    1433,    -1041},
        {     425,      425},
        {     146,     -201},
        {     627,      319},
        {    -244,      753},
        {    -609,      -96},
        {       0,     -320},
        {      32,       -5},
        {     -47,     -147},
        {     189,      -96}
    },
    {
        {       0,        0},     /* Filter 9 */
        {     -28,       87},
        {     142,       22},
        {       0,      449},
        {    -704,      111},
        {    -245,     -756},
        {     501,     -255},
        {     -35,      -48},
        {     748,     -748},
        {    1873,     1361},
        {   -1647,     3233},
        {   -4522,    -1469},
        {     855,    -5400},
        {    5618,        0},
        {     809,     5111},
        {   -4023,     1307},
        {   -1353,    -2655},
        {    1347,     -978},
        {     365,      365},
        {     177,     -244},
        {     645,      328},
        {    -242,      747},
        {    -587,      -93},
        {       0,     -294},
        {      12,       -1},
        {     -50,     -156},
        {     188,      -96}
    },
    {
        {       0,        0},     /* Filter 10 */
        {     -23,       72},
        {     166,       26},
        {       0,      475},
        {    -720,      114},
        {    -243,     -750},
        {     468,     -238},
        {     -76,     -104},
        {     816,     -816},
        {    1962,     1426},
        {   -1695,     3326},
        {   -4596,    -1493},
        {     860,    -5435},
        {    5603,        0},
        {     799,     5050},
        {   -3932,     1277},
        {   -1302,    -2556},
        {    1262,     -917},
        {     307,      307},
        {     207,     -285},
        {     661,      337},
        {    -240,      739},
        {    -565,      -89},
        {       0,     -268},
        {      -6,        1},
        {     -53,     -165},
        {     187,      -95}
    },
    {
        {       0,        0},     /* Filter 11 */
        {     -18,       57},
        {     190,       30},
        {       0,      500},
        {    -734,      116},
        {    -241,     -742},
        {     433,     -221},
        {    -118,     -163},
        {     886,     -886},
        {    2052,     1491},
        {   -1741,     3418},
        {   -4667,    -1516},
        {     865,    -5466},
        {    5584,        0},
        {     789,     4985},
        {   -3839,     1247},
        {   -1252,    -2458},
        {    1178,     -856},
        {     250,      250},
        {     235,     -323},
        {     675,      344},
        {    -237,      730},
        {    -542,      -85},
        {       0,     -242},
        {     -25,        4},
        {     -56,     -172},
        {     185,      -94}
    }
};

==> iaxmodem_1.2.0~dfsg.orig.tar.gz: iaxmodem-1.2.0/lib/spandsp/src/v27ter_rx_2400_fixed_rrc.h <==
#define RX_PULSESHAPER_2400_GAIN        32767.000000f
#define RX_PULSESHAPER_2400_COEFF_SETS  12
static const complexi16_t rx_pulseshaper_2400[RX_PULSESHAPER_2400_COEFF_SETS][27] =
{
    {
        {       0,        0},     /* Filter 0 */
        {     -58,      179},
        {     -42,       -6},
        {       0,      217},
        {    -518,       82},
        {    -233,     -719},
        {     686,     -349},
        {     261,      359},
        {     195,     -195},
        {    1096,      796},
        {   -1202,     2359},
        {   -3745,    -1216},
        {     778,    -4918},
        {    5561,        0},
        {     869,     5492},
        {   -4735,     1538},
        {   -1787,    -3508},
        {    2142,    -1556},
        {     958,      958},
        {    -162,      223},
        {     396,      201},
        {    -238,      732},
        {    -747,     -118},
        {       0,     -524},
        {     215,      -34},
        {     -13,      -41},
        {     167,      -85}
    },
    {
        {       0,        0},     /* Filter 1 */
        {     -56,      172},
        {     -25,       -4},
        {       0,      242},
        {    -542,       85},
        {    -237,     -730},
        {     675,     -344},
        {     235,      323},
        {     250,     -250},
        {    1178,      856},
        {   -1252,     2458},
        {   -3839,    -1247},
        {     789,    -4985},
        {    5584,        0},
        {     865,     5466},
        {   -4667,     1516},
        {   -1741,    -3418},
        {    2052,    -1491},
        {     886,      886},
        {    -118,      163},
        {     433,      221},
        {    -241,      742},
        {    -734,     -116},
        {       0,     -500},
        {     190,      -30},
        {     -18,      -57},
        {     173,      -88}
    },
    {
        {       0,        0},     /* Filter 2 */
        {     -53,      165},
        {      -6,       -1},
        {       0,      268},
        {    -565,       89},
        {    -240,     -739},
        {     661,     -337},
        {     207,      285},
        {     307,     -307},
        {    1262,      917},
        {   -1302,     2556},
        {   -3932,    -1277},
        {     799,    -5050},
        {    5603,        0},
        {     860,     5435},
        {   -4596,     1493},
        {   -1695,    -3326},
        {    1962,    -1426},
        {     816,      816},
        {     -76,      104},
        {     468,      238},
        {    -243,      750},
        {    -720,     -114},
        {       0,     -475},
        {     166,      -26},
        {     -23,      -72},
        {     177,      -90}
    },
    {
        {       0,        0},     /* Filter 3 */
        {     -50,      156},
        {      12,        1},
        {       0,      294},
        {    -587,       93},
        {    -242,     -747},
        {     645,     -328},
        {     177,      244},
        {     365,     -365},
        {    1347,      978},
        {   -1353,     2655},
        {   -4023,    -1307},
        {     809,    -5111},
        {    5618,        0},
        {     855,     5400},
        {   -4522,     1469},
        {   -1647,    -3233},
        {    1873,    -1361},
        {     748,      748},
        {     -35,       48},
        {     501,      255},
        {    -245,      756},
        {    -704,     -111},
        {       0,     -449},
        {     142,      -22},
        {     -28,      -87},
        {     181,      -92}
    },
    {
        {       0,        0},     /* Filter 4 */
        {     -47,      147},
        {      32,        5},
        {       0,      320},
        {    -609,       96},
        {    -244,     -753},
        {     627,     -319},
        {     146,      201},
        {     425,     -425},
        {    1433,     1041},
        {   -1403,     2753},
        {   -4112,    -1336},
        {     818,    -5168},
        {    5628,        0},
        {     849,     5361},
        {   -4445,     1444},
        {   -1599,    -3139},
        {    1784,    -1296},
        {     680,      680},
        {       4,       -6},
        {     531,      270},
        {    -246,      759},
        {    -687,     -108},
        {       0,     -423},
        {     119,      -18},
        {     -32,     -101},
        {     184,      -94}
    },
    {
        {       0,        0},     /* Filter 5 */
        {     -44,      137},
        {      53,        8},
        {       0,      346},
        {    -630,       99},
        {    -246,     -757},
        {     607,     -309},
        {     113,      155},
        {     486,     -486},
        {    1519,     1104},
        {   -1452,     2851},
        {   -4199,    -1364},
        {     827,    -5222},
        {    5634,        0},
        {     842,     5318},
        {   -4366,     1418},
        {   -1551,    -3044},
        {    1695,    -1231},
        {     614,      614},
        {      42,      -58},
        {     559,      284},
        {    -247,      760},
        {    -669,     -106},
        {       0,     -398},
        {      96,      -15},
        {     -37,     -114},
        {     187,      -95}
    },
    {
        {       0,        0},     /* Filter 6 */
        {     -40,      126},
        {      74,       11},
        {       0,      372},
        {    -650,      103},
        {    -247,     -760},
        {     584,     -297},
        {      78,      108},
        {     550,     -550},
        {    1607,     1167},
        {   -1502,     2948},
        {   -4284,    -1391},
        {     835,    -5272},
        {    5637,        0},
        {     835,     5272},
        {   -4284,     1391},
        {   -1502,    -2948},
        {    1607,    -1167},
        {     550,      550},
        {      78,     -108},
        {     584,      297},
        {    -247,      760},
        {    -650,     -103},
        {       0,     -372},
        {      74,      -11},
        {     -40,     -126},
        {     188,      -96}
    },
    {
        {       0,        0},     /* Filter 7 */
        {     -37,      114},
        {      96,       15},
        {       0,      398},
        {    -669,      106},
        {    -247,     -760},
        {     559,     -284},
        {      42,       58},
        {     614,     -614},
        {    1695,     1231},
        {   -1551,     3044},
        {   -4366,    -1418},
        {     842,    -5318},
        {    5634,        0},
        {     827,     5222},
        {   -4199,     1364},
        {   -1452,    -2851},
        {    1519,    -1104},
        {     486,      486},
        {     113,     -155},
        {     607,      309},
        {    -246,      757},
        {    -630,      -99},
        {       0,     -346},
        {      53,       -8},
        {     -44,     -137},
        {     189,      -96}
    },
    {
        {       0,        0},     /* Filter 8 */
        {     -32,      101},
        {     119,       18},
        {       0,      423},
        {    -687,      108},
        {    -246,     -759},
        {     531,     -270},
        {       4,        6},
        {     680,     -680},
        {    1784,     1296},
        {   -1599,     3139},
        {   -4445,    -1444},
        {     849,    -5361},
        {    5628,        0},
        {     818,     5168},
        {   -4112,     1336},
        {   -1403,    -2753},
        {    1433,    -1041},
        {     425,      425},
        {     146,     -201},
        {     627,      319},
        {    -244,      753},
        {    -609,      -96},
        {       0,     -320},
        {      32,       -5},
        {     -47,     -147},
        {     189,      -96}
    },
    {
        {       0,        0},     /* Filter 9 */
        {     -28,       87},
        {     142,       22},
        {       0,      449},
        {    -704,      111},
        {    -245,     -756},
        {     501,     -255},
        {     -35,      -48},
        {     748,     -748},
        {    1873,     1361},
        {   -1647,     3233},
        {   -4522,    -1469},
        {     855,    -5400},
        {    5618,        0},
        {     809,     5111},
        {   -4023,     1307},
        {   -1353,    -2655},
        {    1347,     -978},
        {     365,      365},
        {     177,     -244},
        {     645,      328},
        {    -242,      747},
        {    -587,      -93},
        {       0,     -294},
        {      12,       -1},
        {     -50,     -156},
        {     188,      -96}
    },
    {
        {       0,        0},     /* Filter 10 */
        {     -23,       72},
        {     166,       26},
        {       0,      475},
        {    -720,      114},
        {    -243,     -750},
        {     468,     -238},
        {     -76,     -104},
        {     816,     -816},
        {    1962,     1426},
        {   -1695,     3326},
        {   -4596,    -1493},
        {     860,    -5435},
        {    5603,        0},
        {     799,     5050},
        {   -3932,     1277},
        {   -1302,    -2556},
        {    1262,     -917},
        {     307,      307},
        {     207,     -285},
        {     661,      337},
        {    -240,      739},
        {    -565,      -89},
        {       0,     -268},
        {      -6,        1},
        {     -53,     -165},
        {     187,      -95}
    },
    {
        {       0,        0},     /* Filter 11 */
        {     -18,       57},
        {     190,       30},
        {       0,      500},
        {    -734,      116},
        {    -241,     -742},
        {     433,     -221},
        {    -118,     -163},
        {     886,     -886},
        {    2052,     1491},
        {   -1741,     3418},
        {   -4667,    -1516},
        {     865,    -5466},
        {    5584,        0},
        {     789,     4985},
        {   -3839,     1247},
        {   -1252,    -2458},
        {    1178,     -856},
        {     250,      250},
        {     235,     -323},
        {     675,      344},
        {    -237,      730},
        {    -542,      -85},
        {       0,     -242},
        {     -25,        4},
        {     -56,     -172},
        {     185,      -94}
    }
};
